==> libpappsomspp_0.7.10.orig.tar.gz: libpappsomspp-0.7.10/src/pappsomspp/obo/filterobopsimodtermdiffmono.h <==

/*******************************************************************************
 * Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and
 *implementation
 ******************************************************************************/

#pragma once


#include "obopsimod.h"
#include "../mzrange.h"

namespace pappso
{
class PMSPP_LIB_DECL FilterOboPsiModTermDiffMono
  : public OboPsiModHandlerInterface
{
  private:
  const MzRange m_massRange;
  OboPsiModHandlerInterface &m_sink;

  public:
  FilterOboPsiModTermDiffMono(OboPsiModHandlerInterface &sink,
                              const MzRange &mass_range);
  ~FilterOboPsiModTermDiffMono();

  void setOboPsiModTerm(const OboPsiModTerm &term) override;
};
} // namespace pappso

==> libpappsomspp_0.8.22.orig.tar.gz: libpappsomspp-0.8.22/src/pappsomspp/obo/filterobopsimodtermdiffmono.h <==

/*******************************************************************************
 * Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and
 *implementation
 ******************************************************************************/

#pragma once


#include "obopsimod.h"
#include "../mzrange.h"

namespace pappso
{
class PMSPP_LIB_DECL FilterOboPsiModTermDiffMono
  : public OboPsiModHandlerInterface
{
  private:
  const MzRange m_massRange;
  OboPsiModHandlerInterface &m_sink;

  public:
  FilterOboPsiModTermDiffMono(OboPsiModHandlerInterface &sink,
                              const MzRange &mass_range);
  virtual ~FilterOboPsiModTermDiffMono();

  void setOboPsiModTerm(const OboPsiModTerm &term) override;
};
} // namespace pappso
